Additional interfaces
=====================

TorchIO features can be accessed through the standard Python interface,
the :ref:`Command-line tools <cli>` or the :ref:`3D Slicer GUI <gui>`.

.. toctree::
    :maxdepth: 2

    cli
    slicer
